from data_inclusion.schema.base import EnhancedEnum


class Typologie(EnhancedEnum):
    ACI = (
        "ACI",
        "Structures porteuses d’ateliers et chantiers d’insertion (ACI)",
        None,
    )
    ACIPHC = (
        "ACIPHC",
        "SIAE — Atelier chantier d’insertion premières heures en chantier",
        None,
    )
    AFPA = (
        "AFPA",
        "Agence nationale pour la formation professionnelle des adultes (AFPA)",
        None,
    )
    AI = (
        "AI",
        "Associations intermédiaires (AI)",
        None,
    )
    ASE = (
        "ASE",
        "Aide sociale à l’enfance (ASE)",
        None,
    )
    ASSO = (
        "ASSO",
        "Associations",
        None,
    )
    ASSO_CHOMEUR = (
        "ASSO_CHOMEUR",
        "Associations de chômeurs",
        None,
    )
    Autre = (
        "Autre",
        "Autre",
        None,
    )
    AVIP = (
        "AVIP",
        "Crèche À Vocation d’Insertion Professionnelle (AVIP)",
        None,
    )
    BIB = (
        "BIB",
        "Bibliothèque / Médiathèque",
        None,
    )
    CAARUD = (
        "CAARUD",
        (
            "CAARUD - Centre d’accueil et d’accompagnement à la réduction de risques "
            "pour usagers de drogues"
        ),
        None,
    )
    CADA = (
        "CADA",
        "Centres d’accueil de demandeurs d’asile (CADA)",
        None,
    )
    CAF = (
        "CAF",
        "Caisses d’allocation familiale (CAF)",
        None,
    )
    CAP_EMPLOI = (
        "CAP_EMPLOI",
        "Cap Emploi",
        None,
    )
    CAVA = (
        "CAVA",
        "Centres d’adaptation à la vie active (CAVA)",
        None,
    )
    CC = (
        "CC",
        "Communautés de Commune",
        None,
    )
    CCAS = (
        "CCAS",
        "Centres communaux d’action sociale (CCAS)",
        None,
    )
    CCONS = (
        "CCONS",
        "Chambres consulaires (CCI, CMA, CA)",
        None,
    )
    CD = (
        "CD",
        "Conseils Départementaux (CD)",
        None,
    )
    CDAS = (
        "CDAS",
        "Centre Départementale d'Action Sociale (CDAS)",
        None,
    )
    CFP = (
        "CFP",
        "Centre des Finances Publiques (CFP)",
        None,
    )
    CHRS = (
        "CHRS",
        "Centres d’hébergement et de réinsertion sociale (CHRS)",
        None,
    )
    CHU = (
        "CHU",
        "Centres d’hébergement d’urgence (CHU)",
        None,
    )
    CIAS = (
        "CIAS",
        "Centres intercommunaux d’action sociale (CIAS)",
        None,
    )
    CIDFF = (
        "CIDFF",
        "Centres d’information sur les droits des femmes et des familles (CIDFF)",
        None,
    )
    CITMET = (
        "CITMET",
        "Cité des métiers",
        None,
    )
    CMP = (
        "CMP",
        "Centre Médico-Psychologique (CMP)",
        None,
    )
    CMS = (
        "CMS",
        "Centre Médico-Social (CMS)",
        None,
    )
    CPAM = (
        "CPAM",
        "Caisse Primaire d'Assurance Maladie (CPAM)",
        None,
    )
    CPH = (
        "CPH",
        "Centres provisoires d’hébergement (CPH)",
        None,
    )
    CS = (
        "CS",
        "Centre social",
        None,
    )
    CSAPA = (
        "CSAPA",
        "CSAPA - Centre de soins, d’accompagnement et de prévention en addictologie",
        None,
    )
    CSC = (
        "CSC",
        "Centre Socio-Culturel (CSC)",
        None,
    )
    DEETS = (
        "DEETS",
        "Directions de l’Economie, de l’Emploi, du Travail et des Solidarités (DEETS)",
        None,
    )
    DEPT = (
        "DEPT",
        "Services sociaux du Conseil départemental",
        None,
    )
    DIPLP = (
        "DIPLP",
        (
            "Délégation interministérielles à la prévention et à la lutte contre la "
            "pauvreté"
        ),
        None,
    )
    E2C = (
        "E2C",
        "E2C - École de la 2e chance",
        None,
    )
    EA = (
        "EA",
        "Entreprise adaptée (EA)",
        None,
    )
    EATT = (
        "EATT",
        "Entreprise Adaptée (EATT)",
        None,
    )
    EI = (
        "EI",
        "Entreprises d’insertion (EI)",
        None,
    )
    EITI = (
        "EITI",
        "Entreprises d’insertion par le travail indépendant (EITI)",
        None,
    )
    ENM = (
        "ENM",
        "Espace Numérique Mobile (ENM)",
        None,
    )
    EPCI = (
        "EPCI",
        "Intercommunalité (EPCI)",
        None,
    )
    EPI = (
        "EPI",
        "Espace Public Internet (EPI)",
        None,
    )
    EPIDE = (
        "EPIDE",
        "EPIDE - Établissement pour l’insertion dans l’emploi",
        None,
    )
    EPN = (
        "EPN",
        "Espace Public Numérique (EPN)",
        None,
    )
    ES = (
        "ES",
        "Épicerie Solidaire",
        None,
    )
    ESS = (
        "ESS",
        "Entreprise de l’Économie Sociale et Solidaire",
        None,
    )
    ETABL_PRI = (
        "ETABL_PRI",
        "Établissement privé",
        None,
    )
    ETABL_PUB = (
        "ETABL_PUB",
        "Établissement public",
        None,
    )
    ETAT = (
        "ETAT",
        "Service de l'État",
        None,
    )
    ETTI = (
        "ETTI",
        "Entreprises de travail temporaire d’insertion (ETTI)",
        None,
    )
    EVS = (
        "EVS",
        "Espace de Vie Sociale (EVS)",
        None,
    )
    FABLAB = (
        "FABLAB",
        "Fablab / Atelier partagé",
        None,
    )
    FAIS = (
        "FAIS",
        "Fédérations d’acteurs de l’insertion et de la solidarité",
        None,
    )
    FT = (
        "FT",
        "France Travail",
        None,
    )
    GEIQ = (
        "GEIQ",
        "Groupements d’employeurs pour l’insertion et la qualification (GEIQ)",
        None,
    )
    HUDA = (
        "HUDA",
        "HUDA - Hébergement d’urgence pour demandeurs d’asile",
        None,
    )
    LA_POSTE = (
        "LA_POSTE",
        "Bureau de poste / Agence postale",
        None,
    )
    MDE = (
        "MDE",
        "Maison de l’emploi",
        None,
    )
    MDEF = (
        "MDEF",
        "Maison de l’emploi et de la formation",
        None,
    )
    MDPH = (
        "MDPH",
        "Maison Départementale des Personnes Handicapées",
        None,
    )
    MDS = (
        "MDS",
        "Maison Départementale des Solidarités",
        None,
    )
    MJC = (
        "MJC",
        "Maison des jeunes et de la culture",
        None,
    )
    ML = (
        "ML",
        "Mission Locale",
        None,
    )
    MQ = (
        "MQ",
        "Maison de quartier",
        None,
    )
    MSA = (
        "MSA",
        "Mutualité Sociale Agricole",
        None,
    )
    MSAP = (
        "MSAP",
        "Maison de Services Au Public (MSAP)",
        None,
    )
    MUNI = (
        "MUNI",
        "Municipalités",
        None,
    )
    OACAS = (
        "OACAS",
        (
            "Structures agréées Organisme d’accueil communautaire et d’activité "
            "solidaire (OACAS)"
        ),
        None,
    )
    ODC = (
        "ODC",
        "Organisation délégataire d’un CD",
        None,
    )
    OF = (
        "OF",
        "Organisme de formations",
        None,
    )
    OIL = (
        "OIL",
        "Opérateur d’intermédiation locative",
        None,
    )
    OPCS = (
        "OPCS",
        "Organisation porteuse de la clause sociale",
        None,
    )
    PAD = (
        "PAD",
        "Point d’Accès au Droit",
        None,
    )
    PENSION = (
        "PENSION",
        "Pension de famille / résidence accueil",
        None,
    )
    PI = (
        "PI",
        "Point Information (PI)",
        None,
    )
    PIJ_BIJ = (
        "PIJ_BIJ",
        "Points et bureaux information jeunesse (PIJ/BIJ)",
        None,
    )
    PIMMS = (
        "PIMMS",
        "Point Information Médiation Multi Services (PIMMS)",
        None,
    )
    PJJ = (
        "PJJ",
        "Protection judiciaire de la jeunesse (PJJ)",
        None,
    )
    PLIE = (
        "PLIE",
        "Plans locaux pour l’insertion et l’emploi (PLIE)",
        None,
    )
    PREF = (
        "PREF",
        "Préfecture, Sous-Préfecture",
        None,
    )
    PREVENTION = (
        "PREVENTION",
        "Service ou club de prévention",
        None,
    )
    REG = (
        "REG",
        "Région",
        None,
    )
    RESSOURCERIE = (
        "RESSOURCERIE",
        "Ressourcerie",
        None,
    )
    RFS = (
        "RFS",
        "Réseau France Services",
        None,
    )
    RS_FJT = (
        "RS_FJT",
        "Résidence sociale / FJT - Foyer de Jeunes Travailleurs",
        None,
    )
    SCP = (
        "SCP",
        "Services et clubs de prévention",
        None,
    )
    SPIP = (
        "SPIP",
        "Services pénitentiaires d’insertion et de probation (SPIP)",
        None,
    )
    TIERS_LIEUX = (
        "TIERS_LIEUX",
        "Tiers lieu & coworking",
        None,
    )
    UDAF = (
        "UDAF",
        "Union Départementale d’Aide aux Familles (UDAF)",
        None,
    )
