from data_inclusion.schema.base import EnhancedEnum


class LabelNational(EnhancedEnum):
    SOIXANTE_MILLE_REBONDS = (
        "60000-rebonds",
        "60 000 rebonds",
        None,
    )
    ACTION_LOGEMENT = (
        "action-logement",
        "Action logement",
        None,
    )
    ADIE = (
        "adie",
        "Adie",
        None,
    )
    AFPA = (
        "afpa",
        "AFPA",
        None,
    )
    AGEFIPH = (
        "agefiph",
        "AGEFIPH",
        None,
    )
    AIDANTS_CONNECT = (
        "aidants-connect",
        "Aidants Connect",
        None,
    )
    ALLIANCE_VILLES_EMPLOI = (
        "alliance-villes-emploi",
        "Alliance villes emploi",
        None,
    )
    ANLCI = (
        "anlci",
        "ANLCI",
        None,
    )
    APEC = (
        "apec",
        "APEC",
        None,
    )
    APELS = (
        "apels",
        "APELS Agence Pour l’Education par Le Sport",
        None,
    )
    APPRENTIS_DAUTEUIL = (
        "apprentis-dauteuil",
        "Apprentis d’Auteuil",
        None,
    )
    APTIC = (
        "aptic",
        "APTIC",
        None,
    )
    BANQUES_ALIMENTAIRES = (
        "banques-alimentaires",
        "Banques alimentaires",
        None,
    )
    BGE = (
        "bge",
        "BGE",
        None,
    )
    CAF = (
        "caf",
        "CAF",
        None,
    )
    CAMPUS_CONNECTE = (
        "campus-connecte",
        "Campus connecté",
        None,
    )
    CCI = (
        "cci",
        "CCI",
        None,
    )
    CHANTIER_ECOLE = (
        "chantier-ecole",
        "Chantier école",
        None,
    )
    CAP_EMPLOI_RESEAU_CHEOPS = (
        "cap-emploi-reseau-cheops",
        "CAP Emploi - Réseau CHEOPS",
        None,
    )
    CIDFF = (
        "cidff",
        "CIDFF",
        None,
    )
    CNAM = (
        "cnam",
        "CNAM",
        None,
    )
    COLLECTIF_EMPLOI = (
        "collectif-emploi",
        "Collectif emploi",
        None,
    )
    CONSEILLER_NUMERIQUE = (
        "conseiller-numerique",
        "Conseiller numérique",
        None,
    )
    COORACE = (
        "coorace",
        "Coorace",
        None,
    )
    CREPI = (
        "crepi",
        "CREPI",
        None,
    )
    CRESUS = (
        "cresus",
        "Crésus",
        None,
    )
    CROIX_ROUGE = (
        "croix-rouge",
        "Croix rouge",
        None,
    )
    DIHAL = (
        "dihal",
        "DIHAL",
        None,
    )
    DUO_FOR_A_JOB = (
        "duo-for-a-job",
        "Duo for a job",
        None,
    )
    ECOLES_DE_LA_DEUXIEME_CHANCE = (
        "ecoles-de-la-deuxieme-chance",
        "E2C - École de la 2e chance",
        None,
    )
    EGEE = (
        "egee",
        "EGEE",
        None,
    )
    EMMAUS = (
        "emmaus",
        "Emmaus",
        None,
    )
    ENVIE = (
        "envie",
        "Envie",
        None,
    )
    EPIDE = (
        "epide",
        "EPIDE",
        None,
    )
    ESPACE_EMPLOI_AGRIC_ARRCO = (
        "espace-emploi-agric-arrco",
        "Espace Emploi Agirc Arrco",
        None,
    )
    ETCLD = (
        "etcld",
        "Expérimentation territoriale contre le chômage de longue durée",
        None,
    )
    FABRIQUE_DE_TERRITOIRE = (
        "fabrique-de-territoire",
        "Fabrique de Territoire",
        None,
    )
    FACE = (
        "face",
        "Fondation FACE",
        None,
    )
    FEDE_PRO_FEM = (
        "fede-pro-fem",
        "Federation Professionnelle Pour les Femmes",
        None,
    )
    FEDERATION_DES_ACTEURS_DE_LA_SOLIDARITE = (
        "federation-des-acteurs-de-la-solidarite",
        "Fédération des acteurs de la solidarité",
        None,
    )
    FEDERATION_DES_ENTREPRISES_DINSERTION = (
        "federation-des-entreprises-dinsertion",
        "Fédération des entreprises d’insertion",
        None,
    )
    FORCE_FEMMES = (
        "force-femmes",
        "Force Femmes",
        None,
    )
    FRANCE_ACTIVE = (
        "france-active",
        "France Active",
        None,
    )
    FRANCE_SERVICE = (
        "france-service",
        "France service",
        None,
    )
    FRANCE_TRAVAIL = (
        "france-travail",
        "France Travail",
        None,
    )
    FRENCH_TECH = (
        "french-tech",
        "French Tech",
        None,
    )
    GEIQ = (
        "geiq",
        "GEIQ",
        None,
    )
    GRANDES_ECOLES_DU_NUMERIQUE = (
        "grandes-ecoles-du-numerique",
        "Grand Test Couveuse d’entreprise",
        None,
    )
    GRAND_TEST_COUVEUSE_DENTREPRISE = (
        "grand-test-couveuse-dentreprise",
        "Grandes écoles du numérique",
        None,
    )
    HUP = (
        "hup",
        "H’UP",
        None,
    )
    INAE = (
        "inae",
        "INAE",
        None,
    )
    INITIATIVE_FRANCE = (
        "initiative-france",
        "Initiative France",
        None,
    )
    KONEXIO = (
        "konexio",
        "Konexio",
        None,
    )
    LA_CRAVATE_SOLIDAIRE = (
        "la-cravate-solidaire",
        "La Cravate Solidaire",
        None,
    )
    LA_RESSOURCERIE = (
        "la-ressourcerie",
        "La ressourcerie",
        None,
    )
    LES_PREMIERES = (
        "les-premieres",
        "Les Premières",
        None,
    )
    LINKLUSION = (
        "linklusion",
        "Linklusion",
        None,
    )
    MAISONS_DE_LEMPLOI = (
        "maisons-de-lemploi",
        "Maisons de l’Emploi",
        None,
    )
    MDPH = (
        "mdph",
        "MDPH",
        None,
    )
    MISSION_LOCALE = (
        "mission-locale",
        "Mission Locale",
        None,
    )
    MOBIN = (
        "mobin",
        "Adhérent au Réseau Mob’In",
        None,
    )
    NQT = (
        "nqt",
        "NQT",
        None,
    )
    POINT_CONSEIL_BUDGET = (
        "point-conseil-budget",
        "Point conseil budget",
        None,
    )
    POINT_JUSTICE = (
        "point-justice",
        "Points Justice",
        None,
    )
    POSITIVE_PLANET = (
        "positive-planet",
        "Positive Planet",
        None,
    )
    PROXITE = (
        "proxite",
        "Proxité",
        None,
    )
    RESEAU_APP = (
        "reseau-app",
        "Réseau APP",
        None,
    )
    RESEAU_ENTREPRENDRE = (
        "reseau-entreprendre",
        "Réseau Entreprendre",
        None,
    )
    RESSOURCERIES = (
        "ressourceries",
        "Ressourceries",
        None,
    )
    RESTOS_DU_COEUR = (
        "restos-du-coeur",
        "Restos du coeur",
        None,
    )
    SCCONSEIL = (
        "scconseil",
        "SC Conseil",
        None,
    )
    SECOURS_POPULAIRE = (
        "secours-populaire",
        "Secours populaire",
        None,
    )
    SIAO = (
        "siao",
        "SIAO",
        None,
    )
    SIMPLON = (
        "simplon",
        "Simplon",
        None,
    )
    SINCA = (
        "sinca",
        "SINGA",
        None,
    )
    SNC = (
        "snc",
        "SNC - Solidarité Nouvelle Face au Chômage",
        None,
    )
    SPORT_DANS_LA_VILLE = (
        "sport-dans-la-ville",
        "Sport Dans La Ville",
        None,
    )
    TOUS_TES_POSSIBLE = (
        "tous-tes-possible",
        "Tous Tes Possibles",
        None,
    )
    TZCLD = (
        "tzcld",
        "TZCLD - Territoire Zero Chomeur Longue Durée",
        None,
    )
    UNAF = (
        "unaf",
        "Union nationale de l’aide aux familles",
        None,
    )
    UNAI = (
        "unai",
        "UNAI",
        None,
    )
    UNCCAS = (
        "unccas",
        "Union nationale des centres communaux d’action sociale",
        None,
    )
    UNEA = (
        "unea",
        "UNEA",
        None,
    )
    UNIS_CITE = (
        "unis-cite",
        "Unis-Cité",
        None,
    )
    WIMOOV = (
        "wimoov",
        "Wimoov",
        None,
    )
